| predict.lple | R Documentation |
Compute fitted values and prediction error for a model fitted by lple
## S3 method for class 'lple'
## S3 method for class 'lple'
predict(object, newdata, newy=NULL, ...)
## S3 method for class 'lple'
residuals(object, type=c("martingale", "deviance"), ...)
object |
a model object from the lple fit |
newdata |
optional new data at which to do predictions. If absent, predictions are for the dataframe used in the original fit |
newy |
optional new response data. Default is NULL |
type |
type of residuals, the default is a martingale residual |
... |
additional arguments affecting the predictions produced |
predict.lple is called to predict object from the lple model lple.
The default method, predict has its own help page. Use methods("predict") to get all the methods for the predict generic.
predict.lple returns a list of predicted values, prediction error and residuals.
lp |
linear predictor of beta(w)*Z, where beta(w) is the fitted regression coefficient and Z is covariance matrix. |
risk |
risk score, exp(lp). When new y is provided, both lp and risk will be ordered by survival time of the new y. |
residuals |
martingale residuals of the prediction, if available. |
pe.mres |
prediction error based on martingale residual, if both new data and new y is provided. |
cumhaz |
cumulative hzard function. |
time |
time for cumulative hazard function. Time from new y will be used is provided |
Bingshu E. Chen
The default method for predict predict,
For the Cox model prediction: predict.coxph.
#survfit.lple
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.