| survfit.lple | R Documentation |
Computes the predicted survival function for a model fitted by (lple).
## S3 method for class 'lple'
## S3 method for class 'lple'
survfit(formula, se.fit=TRUE, conf.int=.95, ...)
formula |
a fitted model from (lple) fit |
se.fit |
a logical value indicating whether standard errors shall be computed. Default is TRUE |
conf.int |
The level for a two-sided confidence interval on the survival curve. Default is 0.95 |
... |
other arguments to the specific method |
survfit.lple is called to compuate baseline survival function from the lple model lple.
The default method, survfit has its own help page. Use methods("survfit") to get all the methods for the survfit generic.
survfit.lple returns a list of predicted baseline survival function, cumulative hazard function and residuals.
surv |
Predicted baseline survival function when beta(w) = 0. |
cumhaz |
Baseline cumulative hazard function, -log(surv). |
hazard |
Baseline hazard function. |
varhaz |
Variance of the baseline hazard. |
residuals |
Martingale residuals of the (lple) model. |
std.err |
Standard error for the cumulative hazard function, if se.fit = TRUE. |
See survfit for more detail about other output values such as upper, lower, conf.type.
Confidence interval is based on log-transformation of survival function.
Bingshu E. Chen
The default method for survfit survfit,
#survfit.lple
#
# See example in lple
#
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.